/*===================================================================
 * Copyright(c) AVerMedia TECHNOLOGIES, Inc. 2017
 * All rights reserved
 * =================================================================
 * v4l2_model_table.c
 *
 *  Created on: Apr 15, 2017
 *      Author: 
 *      Version:
 * =================================================================
 */
#include "typedef.h"
#include <linux/kernel.h>
#include <media/videobuf2-core.h>
#include <media/v4l2-device.h>
//#include "sagitta.h"
#include "v4l2_model.h"
#include "v4l2_model_table.h"

static const struct frame_size v4l2_model_frame_size[] = {
    { .width = 640, .height = 480 },
    { .width = 720, .height = 480 },
    { .width = 720, .height = 576 },
    { .width = 800, .height = 600 },
    { .width = 1024, .height = 768 },
    { .width = 1280, .height = 720 },
    { .width = 1280, .height = 768 },
    { .width = 1280, .height = 800 },
    { .width = 1280, .height = 1024 },
    { .width = 1360, .height = 768 },
    { .width = 1440, .height = 900 },
    { .width = 1680, .height = 1050 },
    { .width = 1920, .height = 1080 },
    { .width = 1920, .height = 1200 },
    { .width = 2560, .height = 1080 },
    { .width = 2560, .height = 1440 },
    { .width = 3840, .height = 2160 },
    { .width = 4096, .height = 2160 },
};

static const v4l2_model_timing_t support_videofmt[]= {
    [V4L2_MODEL_VIDEOFORMAT_640X480P60]		= V4L2_MODEL_TIMING(640,480,60,0),
    [V4L2_MODEL_VIDEOFORMAT_720x480I60]		= V4L2_MODEL_TIMING(720,480,60,1),
    [V4L2_MODEL_VIDEOFORMAT_720X480P60]		= V4L2_MODEL_TIMING(720,480,60,0),
    [V4L2_MODEL_VIDEOFORMAT_720X576P50]		= V4L2_MODEL_TIMING(720,480,50,0),
    [V4L2_MODEL_VIDEOFORMAT_800X600P60]		= V4L2_MODEL_TIMING(800,600,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1024X768P60]	= V4L2_MODEL_TIMING(1024,768,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1280X720P50]	= V4L2_MODEL_TIMING(1280,720,50,0),
    [V4L2_MODEL_VIDEOFORMAT_1280X720P60]	= V4L2_MODEL_TIMING(1280,720,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1280X768P60]	= V4L2_MODEL_TIMING(1280,768,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1280X800P60]	= V4L2_MODEL_TIMING(1280,800,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1280X1024P60]	= V4L2_MODEL_TIMING(1280,1024,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1360X768P60]	= V4L2_MODEL_TIMING(1360,768,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1440X900P60]	= V4L2_MODEL_TIMING(1440,900,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1680X1050P60]	= V4L2_MODEL_TIMING(1680,1050,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P24]	= V4L2_MODEL_TIMING(1920,1080,24,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P25]	= V4L2_MODEL_TIMING(1920,1080,25,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P30]	= V4L2_MODEL_TIMING(1920,1080,30,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P50]	= V4L2_MODEL_TIMING(1920,1080,50,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P60]	= V4L2_MODEL_TIMING(1920,1080,60,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P120]	= V4L2_MODEL_TIMING(1920,1080,120,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P144]	= V4L2_MODEL_TIMING(1920,1080,144,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1080P240]	= V4L2_MODEL_TIMING(1920,1080,240,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1200P24]	= V4L2_MODEL_TIMING(1920,1200,24,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1200P25]	= V4L2_MODEL_TIMING(1920,1200,25,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1200P30]	= V4L2_MODEL_TIMING(1920,1200,30,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1200P50]	= V4L2_MODEL_TIMING(1920,1200,50,0),
    [V4L2_MODEL_VIDEOFORMAT_1920X1200P60]	= V4L2_MODEL_TIMING(1920,1200,60,0),
    [V4L2_MODEL_VIDEOFORMAT_2560X1080P60]	= V4L2_MODEL_TIMING(2560,1080,60,0),
    [V4L2_MODEL_VIDEOFORMAT_2560X1080P120]	= V4L2_MODEL_TIMING(2560,1080,120,0),
    [V4L2_MODEL_VIDEOFORMAT_2560X1080P144]	= V4L2_MODEL_TIMING(2560,1080,144,0),
    [V4L2_MODEL_VIDEOFORMAT_2560X1440P60]	= V4L2_MODEL_TIMING(2560,1440,60,0),
    [V4L2_MODEL_VIDEOFORMAT_2560X1440P120]	= V4L2_MODEL_TIMING(2560,1440,120,0),
    [V4L2_MODEL_VIDEOFORMAT_2560X1440P144]	= V4L2_MODEL_TIMING(2560,1440,144,0),
    [V4L2_MODEL_VIDEOFORMAT_3840X2160P24]	= V4L2_MODEL_TIMING(3840,2160,24,0),
    [V4L2_MODEL_VIDEOFORMAT_3840X2160P25]	= V4L2_MODEL_TIMING(3840,2160,25,0),
    [V4L2_MODEL_VIDEOFORMAT_3840X2160P30]	= V4L2_MODEL_TIMING(3840,2160,30,0),
    [V4L2_MODEL_VIDEOFORMAT_3840X2160P50]	= V4L2_MODEL_TIMING(3840,2160,50,0),
    [V4L2_MODEL_VIDEOFORMAT_3840X2160P60]	= V4L2_MODEL_TIMING(3840,2160,60,0),
    [V4L2_MODEL_VIDEOFORMAT_4096X2160P24]	= V4L2_MODEL_TIMING(4096,2160,24,0),
    [V4L2_MODEL_VIDEOFORMAT_4096X2160P25]	= V4L2_MODEL_TIMING(4096,2160,25,0),
    [V4L2_MODEL_VIDEOFORMAT_4096X2160P30]	= V4L2_MODEL_TIMING(4096,2160,30,0),
    [V4L2_MODEL_VIDEOFORMAT_4096X2160P50]	= V4L2_MODEL_TIMING(4096,2160,50,0),
    [V4L2_MODEL_VIDEOFORMAT_4096X2160P60]	= V4L2_MODEL_TIMING(4096,2160,60,0),
};

struct frame_size *v4l2_model_get_frame_size(int index)
{
	if(index < 0 || index >= ARRAY_SIZE(v4l2_model_frame_size))
		return NULL;

	return (struct frame_size *)(v4l2_model_frame_size + index);
}


v4l2_model_timing_t *v4l2_model_get_support_videoformat(int index)
{
	if(index <0 ||index >V4L2_MODEL_VIDEOFORMAT_NUM)
			return NULL;

	return (v4l2_model_timing_t *)&support_videofmt[index];
}




